==> humhub-1.6.4.tar.gz: humhub-1.6.4/protected/humhub/modules/user/messages/ht/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '',
  '<strong>Change</strong> your password' => '',
  '<strong>Join</strong> the network' => '',
  '<strong>Password</strong> changed!' => '',
  '<strong>Password</strong> recovery' => '',
  '<strong>Password</strong> recovery!' => '',
  '<strong>Please</strong> sign in' => '',
  '<strong>Registration</strong> successful!' => '',
  '<strong>Sign</strong> up' => '',
  '<strong>Your account</strong> has been successfully created!' => '',
  'Account' => '',
  'After activating your account by the administrator, you will receive a notification by email.' => '',
  'Back' => 'Tounen',
  'Change password' => '',
  'Create Account' => '',
  'Create account' => '',
  'Don\'t have an account? Join the network by entering your e-mail address.' => '',
  'Enter security code above' => '',
  'Forgot your password?' => '',
  'Go to login page' => '',
  'Group' => '',
  'Hello {displayName}' => '',
  'Hello {displayName},' => '',
  'If you don\'t use this link within 24 hours, it will expire.' => '',
  'If you\'re already a member, please login with your username/email and password.' => '',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => '',
  'Login' => 'Idantifye\'w',
  'New user needs approval' => '',
  'Password recovery' => '',
  'Password reset' => '',
  'Please check your email and follow the instructions!' => '',
  'Please click on the link below to view request:' => '',
  'Please enter the letters from the image.' => '',
  'Please login with your username/email and password.' => '',
  'Please use the following link within the next day to reset your password.' => '',
  'Register' => '',
  'Registration successful' => '',
  'Remember me' => '',
  'Reset Password' => '',
  'Reset password' => '',
  'Sign in' => '',
  'To log in with your new account, click the button below.' => '',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => '',
  'Your email' => '',
  'Your password' => '',
  'Your password has been successfully changed!' => '',
  'Your password is incorrect!' => '',
  'a new user {displayName} needs approval.' => '',
  'back to home' => '',
  'email' => '',
  'password' => '',
  'username or email' => '',
);

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/user/messages/ht/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '',
  '<strong>Change</strong> Password' => '',
  '<strong>Change</strong> your password' => '',
  '<strong>Join</strong> the network' => '',
  '<strong>Password</strong> changed!' => '',
  '<strong>Password</strong> recovery' => '',
  '<strong>Password</strong> recovery!' => '',
  '<strong>Please</strong> sign in' => '',
  '<strong>Registration</strong> successful!' => '',
  '<strong>Sign</strong> up' => '',
  '<strong>Your account</strong> has been successfully created!' => '',
  'Account' => '',
  'After activating your account by the administrator, you will receive a notification by email.' => '',
  'Back' => 'Tounen',
  'Change password' => '',
  'Confirm' => '',
  'Create Account' => '',
  'Create account' => '',
  'Don\'t have an account? Join the network by entering your e-mail address.' => '',
  'Due to security reasons you are required to change your password in order to access the platform.' => '',
  'Enter security code above' => '',
  'Forgot your password?' => '',
  'Go to login page' => '',
  'Group' => '',
  'Hello {displayName}' => '',
  'Hello {displayName},' => 'Bonjou {displayName} ,',
  'If you don\'t use this link within 24 hours, it will expire.' => '',
  'If you\'re already a member, please login with your username/email and password.' => '',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => '',
  'Log out' => '',
  'Login' => 'Idantifye\'w',
  'New user needs approval' => '',
  'Password recovery' => '',
  'Password reset' => '',
  'Please check your email and follow the instructions!' => '',
  'Please click on the link below to view request:' => '',
  'Please enter the letters from the image.' => '',
  'Please login with your username/email and password.' => '',
  'Please use the following link within the next day to reset your password.' => '',
  'Please wait' => '',
  'Register' => '',
  'Registration successful' => '',
  'Remember me' => '',
  'Reset Password' => '',
  'Reset password' => '',
  'Sign in' => '',
  'To log in with your new account, click the button below.' => '',
  'User or Password incorrect.' => '',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => '',
  'Your email' => '',
  'Your password' => '',
  'Your password has been successfully changed!' => '',
  'Your password is incorrect!' => '',
  'a new user {displayName} needs approval.' => '',
  'back to home' => '',
  'email' => '',
  'password' => '',
  'username or email' => '',
);
